<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<xsl:output method="xml" indent="yes" encoding="utf-8" doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"/>
	<xsl:strip-space elements="*"/>
	<xsl:include href="buttons.xsl"/>

	<xsl:template match="LAYOUT">
		<xsl:variable name="cID" select="@ID"/>
		<!-- aa-13 -->
		<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
		<head>
			<title><xsl:value-of select="@SITE-TITLE" disable-output-escaping="yes"/> - <xsl:value-of select="@TITLE" disable-output-escaping="yes"/></title>
			<xsl:apply-templates select="META-TAGS"/>
			<link href="css/styles.css" rel="stylesheet" type="text/css"/>
		</head>
<body style="margin: 0;">
<div class="container">
	<div class="logo-area">
		<!-- LOGO -->
		<img src="images/{LOGO/@NAME}" alt="" border="0"/>
		<h1><xsl:value-of select="COMPANY-INFO/NAME" disable-output-escaping="yes"/></h1>
		<!-- END LOGO -->
	</div>
	<!-- MENU -->
	<xsl:call-template name="TOP-MENU"/>
	<!-- END MENU -->
	<div class="clear"></div>
	<div class="main-area">
		<div class="main-container">
			<div class="left-page">
				<div class="subtitle"><xsl:value-of select="COMPANY-INFO/SLOGAN" disable-output-escaping="yes"/></div>
				<img src="images/header.jpg" alt="" border="0"/>
				<!-- SUBMENU -->
				<xsl:call-template name="SUB-MENU"><xsl:with-param name="pageID" select="@ID"/></xsl:call-template>
				<!-- END SUBMENU -->
			</div>
			<div class="right-page">
				<div class="pagetitle"><xsl:value-of select="@TITLE" disable-output-escaping="yes"/></div>
				<div class="pageContent content">
					<!-- CONTENT -->
					<xsl:apply-templates select="PAGE-CONTENT"/>
					<!-- END CONTENT -->
				</div>
			</div>
		</div>
	</div>
	<div class="clear"></div>
	<!-- FOOTER -->
	<div class="footer"><xsl:value-of select="COPYRIGHT" disable-output-escaping="yes"/></div>
	<!-- END FOOTER -->	
</div>
</body>		
		<!--sw_sb_ms-->
		</html>
	</xsl:template>


<xsl:template name="TOP-MENU">
		<xsl:apply-templates select="MENU" mode="top"/>	
</xsl:template>


<xsl:template name="SUB-MENU">
	<xsl:param name="pageID"/>	
	<xsl:if test="//MENU/MENU-ITEM[@ID = $pageID]/MENU-ITEM or //MENU/MENU-ITEM/MENU-ITEM[@ID = $pageID]">
		<ul class="submenu">	
			<xsl:choose>
				<xsl:when test="//MENU/MENU-ITEM[@ID = $pageID]/MENU-ITEM">
					<xsl:apply-templates select="//MENU/MENU-ITEM[@ID = $pageID]/MENU-ITEM" mode="sub"/>
				</xsl:when>
				<xsl:when test="//MENU/MENU-ITEM/MENU-ITEM[@ID = $pageID]">
					<xsl:variable name="parentID" select="//MENU/MENU-ITEM/MENU-ITEM[@ID = $pageID]/../@ID"/>
					<xsl:apply-templates select="//MENU/MENU-ITEM[@ID=$parentID]/MENU-ITEM" mode="sub"/>
				</xsl:when>
			</xsl:choose>
		</ul>
		<div class="clear"></div>
	</xsl:if>
</xsl:template>		
	
<xsl:template match="MENU-ITEM" mode="sub">
	<xsl:choose>
		<!--active-->
		<xsl:when test="@ID=/LAYOUT/@ID" >
			<li class="active">
				<a href="{@HREF}" class="text"><xsl:value-of select="@TITLE" disable-output-escaping="yes"/></a>
				<a href="{@HREF}" class="bullet">
					<xsl:variable name="curpos" select="position()"/>
					<xsl:variable name="hidden" select="count(../MENU-ITEM[@HIDDEN='1' and position()&lt;$curpos])"/>
					<xsl:variable name="pos" select="$curpos - $hidden"/>
					<xsl:if test="$pos &lt; 10">0</xsl:if>
					<xsl:value-of select="$pos"/>
				</a>
			</li>
		</xsl:when>
		<!--inactive-->
		<xsl:otherwise>
			<xsl:if test="../MENU-ITEM[@ID=/LAYOUT/@ID] or ../../MENU-ITEM[@ID=/LAYOUT/@ID]">
				<li>
					<a href="{@HREF}" class="text"><xsl:value-of select="@TITLE" disable-output-escaping="yes"/></a>
					<a href="{@HREF}" class="bullet">
						<xsl:variable name="curpos" select="position()"/>
						<xsl:variable name="hidden" select="count(../MENU-ITEM[@HIDDEN='1' and position()&lt;$curpos])"/>
						<xsl:variable name="pos" select="$curpos - $hidden"/>
		                <xsl:if test="$pos &lt; 10">0</xsl:if>
		                <xsl:value-of select="$pos"/>
					</a>
				</li>
			</xsl:if>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:if test="position()!=last()">
		<!-- separator -->
		<li class="separator"><div><span></span></div></li>
	</xsl:if>
</xsl:template>	
	
<xsl:template match="META-TAGS">
	<xsl:apply-templates mode="meta-tags"/>
</xsl:template>
	
<xsl:template match="*" mode="meta-tags">
	<meta name="{local-name(.)}"><xsl:attribute name="content"><xsl:value-of select="."/></xsl:attribute></meta>
</xsl:template>


<xsl:template match="PAGE-CONTENT">
	<xsl:comment> EDITABLE CONTENT </xsl:comment>
	<xsl:apply-templates mode="meta-tags"/>
</xsl:template>
	     	
</xsl:stylesheet>
